==> SIMATH-3.8.1.tar.gz: SIMATH-3.8.1/sim/_calc.h <==
#include<config.h>
#include <_pol4.h>
#include <signal.h>
#include <site.h>

# define putpm( r, P, V ) fputpm( r, P, V, stdout )

#undef putgfsel
# define putgfsel( a, V ) fputgfsel( a, V, stdout )

#undef putgf2el
# define putgf2el( G, a, V ) fputgf2el( G, a, V, stdout )

#undef putpgfs
# define putpgfs( r, P, VL, V ) fputpgfs( r, P, VL, V, stdout )

#undef putpgf2
# define putpgf2( r, G, P, VL, V ) fputpgf2( r, G, P, VL, V, stdout )

# ifndef ___MX

#undef printf
#define printf yprintf

#undef putc
# define putc(c,pf) xputc(c)

#undef puti
# define puti yputi

#undef putr
# define putr yputr

#undef putrd
# define putrd yputrd

#undef puta
# define puta yputa

#undef putl
# define putl yputl

#undef putpi
# define putpi yputpi

#undef putpr
# define putpr yputpr

#undef puts
# define puts yputs

#undef puto
# define puto(a) (isatom(a)?yputa(a):yputl(a))

#undef putbits
# define putbits yputbits

#undef putfl
# define putfl yputfl

#undef putflfx
# define putflfx yputflfx

#undef putnfel
# define putnfel yputnfel
	
#undef putqnfid
# define putqnfid yputqnfid

#undef putpnf 
# define putpnf yputpnf

#undef putpm 
# define putpm yputpm

#undef putgfsel
# define putgfsel yputgfsel

# undef putgf2el
# define putgf2el yputgf2el

# undef putpgfs
# define putpgfs yputpgfs

# undef putpgf2
# define putpgf2 yputpgf2

#endif

# define strcat2( s,a,b ) ( *s='\0', strcat(strcat(s,a),b) )
#define  strcat3( s,a,b,c )  strcat( strcat2( s,a,b ), c )
#define  strcat4( s,a,b,c,d )  strcat( strcat( strcat2( s,a,b ), c ), d )
#define itoc(N) (N ? ( issingle(N) ? list2(list2(0,N),0) : list2(flcons(N,0,llength(N)),0) ) : 0)
#define fltoc(N) (N ? list2(N,0) : 0)

# define gf2elred(Gn,a,Gm)  udpm2togf2el(Gm,gf2eltoudpm2(Gn,a)) 
# define gfselred(p,a,Gm) pmsrem(1,p,pitopms(1,a,p),Gm)

# ifdef ___APOLLO
# ifndef ___APO10000
# define ___APO_RAM    /** fuer APOLLO 3000, APOLLO 4500 **/
# endif
# endif

#define MAXLV 5000
#define MAXL 10000
#define  NUM_FUNC 162 
# ifdef ___APO_RAM
# define VARLISTLENGTH 262
# else
#define  VARLISTLENGTH 462
# endif
extern struct var{
	char *varname;
	single typ;
	obj varwert;
} varlist[VARLISTLENGTH];

char *malloc();
long time();
FILE *fopen();

extern FILE *datei, *fpt[10];
extern char *comm,*dhelp, *datn, *fname[10];
extern single ps, hps, as, cellc, cellabs, tdiff, tabs, statsch, owsch, fz, DIGITS, MX;
extern single ecqnfsch, ecsch, modsch, ssch, pzsch, nfsch, gfsch; 
extern single gfchar;
extern single fosch, schleife, breaksch;
extern list VNF, VGF;

#ifdef ___MX
# ifndef ___MX300
char *gctime();
# else
char *ctime();
# endif
# else
char *ctime();
# endif

==> SIMATH-3.9.tar.gz: SIMATH-3.9/sim/_calc.h <==
#include<config.h>
#include <_pol4.h>
#include <signal.h>

# define putpm( r, P, V ) fputpm( r, P, V, stdout )

#undef putgfsel
# define putgfsel( a, V ) fputgfsel( a, V, stdout )

#undef putgf2el
# define putgf2el( G, a, V ) fputgf2el( G, a, V, stdout )

#undef putpgfs
# define putpgfs( r, P, VL, V ) fputpgfs( r, P, VL, V, stdout )

#undef putpgf2
# define putpgf2( r, G, P, VL, V ) fputpgf2( r, G, P, VL, V, stdout )

# ifndef ___MX

#undef printf
#define printf yprintf

#undef putc
# define putc(c,pf) xputc(c)

#undef puti
# define puti yputi

#undef putr
# define putr yputr

#undef putrd
# define putrd yputrd

#undef puta
# define puta yputa

#undef putl
# define putl yputl

#undef putpi
# define putpi yputpi

#undef putpr
# define putpr yputpr

#undef puts
# define puts yputs

#undef puto
# define puto(a) (isatom(a)?yputa(a):yputl(a))

#undef putbits
# define putbits yputbits

#undef putfl
# define putfl yputfl

#undef putflfx
# define putflfx yputflfx

#undef putnfel
# define putnfel yputnfel
	
#undef putqnfid
# define putqnfid yputqnfid

#undef putpnf 
# define putpnf yputpnf

#undef putpm 
# define putpm yputpm

#undef putgfsel
# define putgfsel yputgfsel

# undef putgf2el
# define putgf2el yputgf2el

# undef putpgfs
# define putpgfs yputpgfs

# undef putpgf2
# define putpgf2 yputpgf2

#endif

#define strcat2( s,a,b ) ( *s='\0', strcat(strcat(s,a),b) )
#define  strcat3( s,a,b,c )  strcat( strcat2( s,a,b ), c )
#define  strcat4( s,a,b,c,d )  strcat( strcat( strcat2( s,a,b ), c ), d )
#define itoc(N) (N ? ( issingle(N) ? list2(list2(0,N),0) : list2(flcons(N,0,llength(N)),0) ) : 0)
#define fltoc(N) (N ? list2(N,0) : 0)

# define gf2elred(Gn,a,Gm)  udpm2togf2el(Gm,gf2eltoudpm2(Gn,a)) 
# define gfselred(p,a,Gm) pmsrem(1,p,pitopms(1,a,p),Gm)

# ifdef ___APOLLO
# define ___APO_RAM    /** fuer APOLLO 3000, APOLLO 4500 **/
# endif

# ifdef ___LARGE_SYSTEM
#define MAXLV 50000
#define MAXL 100000
# else
#define MAXLV 5000
#define MAXL 10000
# endif 

#define  NUM_FUNC 180 
# ifdef ___APO_RAM
# define VARLISTLENGTH 280
# else
#define  VARLISTLENGTH 480
# endif
extern struct var{
	char *varname;
	single typ;
	obj varwert;
} varlist[VARLISTLENGTH], localvar[VARLISTLENGTH];

# define USER_FUNC 50

extern char *funstr[USER_FUNC];

char *malloc();
long time();
FILE *fopen();

extern FILE *datei, *fpt[10];
extern char *comm,*dhelp, *datn, *fname[10];
extern single ps, hps, cellc, cellabs, tdiff, tabs, statsch, owsch, owalt, fz, DIGITS, OUTPUTDIG, MX, MXNUM, MXUSER, DEPTH;
extern floating HEIGHTBOUND;
extern single ecqnfsch, ecsch, modsch, ssch, pzsch, nfsch, gfsch; 
extern single gfchar;
extern single fosch, schleife, breaksch;
extern single assch,prfehl;
extern list VNF, VGF;
extern single anzloc, funktion;

#ifdef ___MX
# ifndef ___MX300
char *gctime();
# else
char *ctime();
# endif
# else
char *ctime();
# endif
